@@ -1,6 +1,6 @@
 #! /usr/local/bin/perl
 
-$VERSION = '0.01';
+$VERSION = '0.02';
 
 use strict;
 #use warnings; 
@@ -8,7 +8,8 @@ use strict;
 use Data::Dumper;
 use ExtUtils::MakeMaker;
 
-our(%convert,
+our(
+    %convert,
     %sorted_order,
     %default_args,
     $header,
@@ -17,15 +18,15 @@ our(%convert,
 );
 
 
-my $MAKEFILE_PL = 'Makefile.PL';
-my $BUILD_PL    = 'Build.PL';
+my $MAKEFILE_PL    = 'Makefile.PL';
+my $BUILD_PL       = 'Build.PL';
 
-my $DEBUG      = 0;
-my $LEN_INTEND = 3;
+my $DEBUG          = 0;
+my $LEN_INTEND     = 3;
 
 # Data::Dumper
-my $DD_INDENT    = 2;
-my $DD_SORTKEYS  = 1;
+my $DD_INDENT      = 2;
+my $DD_SORTKEYS    = 1;
 
 
 *ExtUtils::MakeMaker::WriteMakefile = \&_convert;
@@ -39,7 +40,8 @@ sub _run_makefile {
 }
 
 sub _convert {
-    local(%convert, 
+    local(
+          %convert, 
           %sorted_order, 
 	  %default_args,
 	  $header,
@@ -57,34 +59,30 @@ sub _get_data {
     local $/ = '1;';
     local $_ = <DATA>;
     
-    #  # description
-    #  -
-    my $regexp = qr/#\s+.*\s+?-\s+?\n/;
-    my @data = split /$regexp/;
+    my $regexp = qr/#\s+.*\s+?-\s+?\n/;    #  # description
+    my @data = split /$regexp/;            #  -
     
-    # Superfluos items
-    shift @data;
-    chomp $data[-1]; $/ = "\n";   
+    shift @data;                           # Superfluos items			
+    chomp $data[-1]; $/ = "\n";            
     chomp $data[-1];
     
-    %convert      = split /\s+/, shift @data;
-    %sorted_order = split /\s+/, shift @data;
-    %default_args = split /\s+/, shift @data;
-    $header       = shift @data;
-    $footer       = shift @data;
+    %convert         = split /\s+/, shift @data;
+    %sorted_order    = split /\s+/, shift @data;
+    %default_args    = split /\s+/, shift @data;
+    $header          = shift @data;
+    $footer          = shift @data;
 }
 
 sub _args_build { 
     my %args_make = @_;
-    my @args_build = (_insert_args()); 
+    my @args_build = (\%default_args); 
     
     for my $arg (keys %args_make) {
         next unless $convert{$arg};
 	
-	# HASH CONVERSION
-        if (ref $args_make{$arg} eq 'HASH') { 
+        if (ref $args_make{$arg} eq 'HASH') {                             ### HASH CONVERSION
  	    my(%subargs, $count_subargs);  
-	    my($total_subargs) = scalar %{$args_make{$arg}} =~ /^(.)/;
+	    my($total_subargs) = scalar %{$args_make{$arg}} =~ /^(.)/;    
 	    
 	    for my $subarg (keys %{$args_make{$arg}}) {
 	        $subargs{$subarg} = $args_make{$arg}{$subarg};
@@ -94,15 +92,14 @@ sub _args_build {
 	    %{$tmphash{$convert{$arg}}} = %subargs;
 	    push @args_build, \%tmphash;
 	}
-	# ARRAY CONVERSION
-	elsif (ref $args_make{$arg} eq 'ARRAY') {
+	elsif (ref $args_make{$arg} eq 'ARRAY') {                         ### ARRAY CONVERSION
 	    warn "Warning: $arg - array conversion not supported\n";
 	}
-	# SCALAR CONVERSION
 	#
 	# One-dimensional hash values (scalars),
 	# don't justify as SCALARS.
-        elsif (ref $args_make{$arg} eq '') { 	
+	#
+        elsif (ref $args_make{$arg} eq '') { 	                          ### SCALAR CONVERSION
 	    my %tmphash;
 	    $tmphash{$convert{$arg}} = $args_make{$arg};
 	    push @args_build, \%tmphash;
@@ -112,15 +109,11 @@ sub _args_build {
 	}
     }    
     
-    @args_build = @{_sort(\@args_build)} if %sorted_order;
+    @args_build = @{_sort(\@args_build)}    if %sorted_order;
     
     return \@args_build;
 }
 
-sub _insert_args { 
-    return \%default_args;
-}
-
 sub _sort {
     my($args) = @_;
     
@@ -145,10 +138,10 @@ sub _sort {
 sub _dump {
     my($args) = @_;
 
-    $Data::Dumper::Indent    = $DD_INDENT || 2;
-    $Data::Dumper::Quotekeys = 0;
-    $Data::Dumper::Sortkeys  = $DD_SORTKEYS;
-    $Data::Dumper::Terse     = 1;
+    $Data::Dumper::Indent       = $DD_INDENT || 2;
+    $Data::Dumper::Quotekeys    = 0;
+    $Data::Dumper::Sortkeys     = $DD_SORTKEYS;
+    $Data::Dumper::Terse        = 1;
     
     my $d = Data::Dumper->new([ @$args ]);
     
@@ -180,7 +173,7 @@ sub _write_header {
     local $INTEND = $INTEND;
     chop($INTEND);
     
-    $header =~ s/\$INTEND/$INTEND/g;
+    $header =~ s{\$INTEND}{$INTEND}g;
     
     _debug("\n$BUILD_PL written:\n");
     _debug($header);
@@ -191,68 +184,48 @@ sub _write_header {
 sub _write_args {
     my($args) = @_;
     
-    for my $arg (@$args) {
-        # HASH OUTPUT 
-        if ($arg =~ m#=> \{#o) {
-	    # Remove redundant parentheses
-	    $arg =~ s#^ \{ .*?\n (.*? \}) \s+ \} $#$1#osx;
+    for my $arg (@$args) {                                        
+        if ($arg =~ m#=> \{#o) {                                     ### HASH OUTPUT
+	    $arg =~ s#^ \{ .*?\n (.*? \}) \s+ \} $#$1#osx;           # Remove redundant parentheses
 	    
-	    my @arg = @{_split_arg($arg)};
+	    my @arg;        
+            while ($arg =~ s#^ (.*?\n) (.*) $#$2#osx) {              # One element per each line
+                push @arg, $1;
+            };
+	    
+	    my($whitespace) = $arg[0] =~ m#^ (\s+) (?: \w+)#ox;      # Gather whitespace up to hash key in order 
+	    my $shorten = length($whitespace);                       # to recreate native Dump() intendation.
 	    
-	    # Gather whitespace up to hash key in order 
-	    # to recreate native Dump() intendation.
-	    my($whitespace) = $arg[0] =~ m#^ (\s+) (?: \w+)#ox;
-	    my $shorten = length($whitespace);
-
             for my $arg (@arg) {
 	        chomp($arg);
 		
-		# Remove additional whitespace
-	        $arg =~ s#^ \s{$shorten} (.*) $#$1#ox;
-		# Add quotes to hash keys within multiple hashes
-		$arg =~ s#(\S+) => (\w+)#'$1' => $2#o;
-		# Remove quotes on version numbers
-		$arg =~ s# '(\d+)' (?: , | ) $#$1#ox;
-		# Add comma where appropriate (version numbers, parentheses)
-	        $arg .= ',' if ($arg =~ m#(?: \d+ | \}) $#ox);
+	        $arg =~ s#^ \s{$shorten} (.*) $#$1#ox;               # Remove additional whitespace
+		$arg =~ s#(\S+) => (\w+)#'$1' => $2#o;               # Add quotes to hash keys within multiple hashes
+		$arg =~ s# '(\d+)' (?: , | ) $#$1#ox;                # Remove quotes on version numbers
+	        $arg .= ','    if ($arg =~ m#(?: \d+ | \}) $#ox);    # Add comma where appropriate (version numbers, parentheses)
 		
 		_debug("$INTEND$arg\n");
 		
 		print "$INTEND$arg\n";
             }
 	}
-	# SCALAR OUTPUT
-	else {
+	else {                                                       ### SCALAR OUTPUT
 	    chomp($arg);
 	
-	    # Remove redundant parentheses
-            $arg =~ s#^ \{ \s+ (.*) \s+ \} $#$1#ox;
+            $arg =~ s#^ \{ \s+ (.*) \s+ \} $#$1#ox;                  # Remove redundant parentheses
 	    
-	    _debug("$INTEND$arg\n");
+	    _debug("$INTEND$arg,\n");
 	    
 	    print "$INTEND$arg,\n";
 	}
     }
 }
 
-sub _split_arg {
-    my($arg) = @_;
-    
-    my @arg;
-    
-    # One element per each line        
-    while ($arg =~ s#^ (.*?\n) (.*) $#$2#osx) {
-        push @arg, $1;
-    }
-    
-    return \@arg;
-}
-
 sub _write_footer {
     local $INTEND = $INTEND;
     chop($INTEND);
     
-    $footer =~ s/\$INTEND/$INTEND/g;
+    $footer =~ s{\$INTEND}{$INTEND}g;
     
     _debug($footer);
     
@@ -267,7 +240,7 @@ sub _close_build_pl {
 }
 
 sub _debug { 
-    print STDOUT @_ if $DEBUG; 
+    print STDOUT @_    if $DEBUG; 
 }
 
 __DATA__
